'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@vue-storefront/core');
var shopifyApollo = require('@vue-storefront/shopify-apollo');

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function getProduct(context, params, customQuery) {
    if (params.slug) {
        let chosenVariant = [];
        if (params.selectedOptions && Object.keys(params.selectedOptions).length > 0) {
            chosenVariant = Object.entries(params.selectedOptions).map(k => ({ name: k[0], value: k[1] }));
        }
        const getProductByHandleQuery = context.client.graphQLClient.query((root) => {
            root.add('productByHandle', { args: { handle: params.slug } }, (productByHandle) => {
                // get product basic information
                productByHandle.add('id');
                productByHandle.add('title');
                productByHandle.add('description');
                productByHandle.add('descriptionHtml');
                productByHandle.add('handle');
                productByHandle.add('tags');
                productByHandle.add('availableForSale');
                productByHandle.add('totalInventory');
                productByHandle.add('vendor');
                productByHandle.addField('seo', (seoData) => {
                    seoData.add('title');
                    seoData.add('description');
                });
                productByHandle.addConnection('metafields', { args: { first: 20 } }, (metafields) => {
                    metafields.add('id');
                    metafields.add('createdAt');
                    metafields.add('updatedAt');
                    metafields.add('namespace');
                    metafields.add('type');
                    metafields.add('key');
                    metafields.add('value');
                });
                productByHandle.add('variantBySelectedOptions', { args: { selectedOptions: chosenVariant } }, (selectedVariant) => {
                    selectedVariant.add('id');
                    selectedVariant.add('title');
                    selectedVariant.add('sku');
                    selectedVariant.add('availableForSale');
                    selectedVariant.add('quantityAvailable');
                    selectedVariant.addField('image', { args: {} }, (image) => {
                        image.add('altText');
                        image.add('originalSrc');
                        image.add('transformedSrc');
                    });
                    selectedVariant.addField('priceV2', (price) => {
                        price.add('amount');
                        price.add('currencyCode');
                    });
                    selectedVariant.addField('compareAtPriceV2', (price) => {
                        price.add('amount');
                        price.add('currencyCode');
                    });
                });
                productByHandle.add('options', {}, (options) => {
                    options.add('name');
                    options.add('values');
                });
                productByHandle.addConnection('collections', { args: { first: 20 } }, (collection) => {
                    collection.add('title');
                    collection.add('handle');
                });
                productByHandle.addConnection('images', { args: { first: 20 } }, (image) => {
                    image.add('id');
                    image.add('altText');
                    image.add('originalSrc');
                    image.add('transformedSrc');
                });
                productByHandle.addConnection('variants', { args: { first: 1 } }, (variants) => {
                    variants.add('title');
                    variants.add('price');
                    variants.add('weight');
                    variants.add('availableForSale');
                    variants.add('sku');
                    variants.add('compareAtPrice');
                    variants.addField('image', { args: {} }, (image) => {
                        image.add('id');
                        image.add('altText');
                        image.add('originalSrc');
                        image.add('transformedSrc');
                    });
                    variants.addField('selectedOptions', {}, (selectedOptions) => {
                        selectedOptions.add('name');
                        selectedOptions.add('value');
                    });
                    variants.addField('product', {}, (product) => {
                        product.add('id');
                        product.add('title');
                        product.add('availableForSale');
                        product.add('handle');
                        product.add('description');
                        product.add('descriptionHtml');
                        product.addConnection('images', { args: { first: 20 } }, (images) => {
                            images.add('id');
                            images.add('altText');
                            images.add('originalSrc');
                            images.add('transformedSrc');
                        });
                        product.add('productType');
                        product.addField('options', {}, (options) => {
                            options.add('name');
                            options.add('values');
                        });
                    });
                });
            });
        });
        return context.client.graphQLClient
            .send(getProductByHandleQuery)
            .then(({ model, product }) => {
            if (model) {
                return model.productByHandle;
            }
        });
    }
    else if (params.related) {
        const getrelatedProductsByIdQuery = context.client.graphQLClient.query((root) => {
            root.add('productRecommendations', { args: { productId: params.productId } }, (relatedProductsById) => {
                // get product basic information
                relatedProductsById.add('id');
                relatedProductsById.add('title');
                relatedProductsById.add('handle');
                relatedProductsById.add('options', {}, (options) => {
                    options.add('name');
                    options.add('values');
                });
                relatedProductsById.addConnection('images', { args: { first: 20 } }, (image) => {
                    image.add('id');
                    image.add('altText');
                    image.add('originalSrc');
                    image.add('transformedSrc');
                });
                relatedProductsById.addConnection('collections', { args: { first: 20 } }, (collection) => {
                    collection.add('title');
                    collection.add('handle');
                });
                relatedProductsById.addConnection('variants', { args: { first: 20 } }, (variants) => {
                    variants.add('title');
                    variants.add('price');
                    variants.add('weight');
                    variants.add('availableForSale');
                    variants.add('sku');
                    variants.add('compareAtPrice');
                    variants.addField('image', { args: {} }, (image) => {
                        image.add('id');
                        image.add('altText');
                        image.add('originalSrc');
                        image.add('transformedSrc');
                    });
                    variants.addField('selectedOptions', {}, (selectedOptions) => {
                        selectedOptions.add('name');
                        selectedOptions.add('value');
                    });
                    variants.addField('product', {}, (product) => {
                        product.add('id');
                        product.add('title');
                        product.add('availableForSale');
                        product.add('handle');
                        product.add('description');
                        product.add('descriptionHtml');
                        product.addConnection('images', { args: { first: 20 } }, (images) => {
                            images.add('id');
                            images.add('altText');
                            images.add('originalSrc');
                            images.add('transformedSrc');
                        });
                        product.add('productType');
                        product.addField('options', {}, (options) => {
                            options.add('name');
                            options.add('values');
                        });
                    });
                });
            });
        });
        return context.client.graphQLClient
            .send(getrelatedProductsByIdQuery)
            .then(({ model }) => {
            if (model) {
                return model.productRecommendations;
            }
        });
    }
    else if (params.id) {
        return await context.client.product.fetch(params.id).then((product) => {
            return product;
        });
    }
    else if (params.ids) {
        return await context.client.product.fetchMultiple(params.ids).then((products) => {
            return products;
        });
    }
    else {
        return await context.client.product
            .fetchQuery({ first: (params.limit ? params.limit : 20), sortKey: (params.sortBy ? params.sortBy : 'CREATED_AT'), reverse: false })
            .then((products) => {
            return products;
        });
    }
}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function getCategory(context, params, customQuery) {
    // Use the built-in function
    if (params.slug !== '') {
        return context.client.collection.fetchByHandle(params.slug).then((collection) => {
            // Collection with all default fields
            return collection;
        });
    }
    else {
        return context.client.collection.fetchAll().then((collection) => {
            // Collection with all default fields
            return collection;
        });
    }
}

/* TODO: Fetch custom client directly, may be using context  */
const changePasswordMutation = (context) => {
    const customerAccessToken = context.client.graphQLClient.variable('customerAccessToken', 'String!');
    const customer = context.client.graphQLClient.variable('customer', 'CustomerUpdateInput!');
    return context.client.graphQLClient.mutation('customerUpdate', [customerAccessToken, customer], (root) => {
        root.add('customerUpdate', { args: { customerAccessToken, customer } }, (customer) => {
            customer.add('customer', (fields) => {
                fields.add('id');
                fields.add('displayName');
                fields.add('email');
                fields.add('firstName');
                fields.add('lastName');
                fields.add('phone');
            });
            customer.add('customerAccessToken', (token) => {
                token.add('accessToken');
                token.add('expiresAt');
            });
            customer.add('customerUserErrors', (error) => {
                error.add('code');
                error.add('field');
                error.add('message');
            });
        });
    });
};
const forgotPasswordMutation = (context) => {
    const email = context.client.graphQLClient.variable('email', 'String!');
    return context.client.graphQLClient.mutation('customerRecover', [email], (root) => {
        root.add('customerRecover', { args: { email } }, (customer) => {
            customer.add('customerUserErrors', (error) => {
                error.add('code');
                error.add('field');
                error.add('message');
            });
        });
    });
};
const customerAddressDeleteMutation = (context) => {
    const id = context.client.graphQLClient.variable('id', 'ID!');
    const customerAccessToken = context.client.graphQLClient.variable('customerAccessToken', 'String!');
    return context.client.graphQLClient.mutation('customerAddressDelete', [id, customerAccessToken], (root) => {
        root.add('customerAddressDelete', { args: { id, customerAccessToken } }, (customer) => {
            customer.add('customerUserErrors', (error) => {
                error.add('code');
                error.add('field');
                error.add('message');
            });
            customer.add('deletedCustomerAddressId');
        });
    });
};
const customerAddressAddMutation = (context) => {
    const address = context.client.graphQLClient.variable('address', 'MailingAddressInput!');
    const customerAccessToken = context.client.graphQLClient.variable('customerAccessToken', 'String!');
    return context.client.graphQLClient.mutation('customerAddressCreate', [customerAccessToken, address], (root) => {
        root.add('customerAddressCreate', { args: { address, customerAccessToken } }, (customer) => {
            customer.add('customerAddress', (addressInfo) => {
                addressInfo.add('id');
            });
            customer.add('customerUserErrors', (error) => {
                error.add('code');
                error.add('field');
                error.add('message');
            });
        });
    });
};
const customerAddressUpdateMutation = (context) => {
    const customerAccessToken = context.client.graphQLClient.variable('customerAccessToken', 'String!');
    const id = context.client.graphQLClient.variable('id', 'ID!');
    const address = context.client.graphQLClient.variable('address', 'MailingAddressInput!');
    return context.client.graphQLClient.mutation('customerAddressUpdate', [customerAccessToken, id, address], (root) => {
        root.add('customerAddressUpdate', { args: { address, id, customerAccessToken } }, (customer) => {
            customer.add('customerAddress', (addressInfo) => {
                addressInfo.add('id');
            });
            customer.add('customerUserErrors', (error) => {
                error.add('code');
                error.add('field');
                error.add('message');
            });
        });
    });
};
const editProfileMutation = (context) => {
    const customerAccessToken = context.client.graphQLClient.variable('customerAccessToken', 'String!');
    const customer = context.client.graphQLClient.variable('customer', 'CustomerUpdateInput!');
    return context.client.graphQLClient.mutation('customerUpdate', [customerAccessToken, customer], (root) => {
        root.add('customerUpdate', { args: { customerAccessToken, customer } }, (customer) => {
            customer.add('customer', (fields) => {
                fields.add('id');
                fields.add('displayName');
                fields.add('email');
                fields.add('firstName');
                fields.add('lastName');
                fields.add('phone');
            });
            customer.add('customerAccessToken', (token) => {
                token.add('accessToken');
                token.add('expiresAt');
            });
            customer.add('customerUserErrors', (error) => {
                error.add('code');
                error.add('field');
                error.add('message');
            });
        });
    });
};
const signInMutation = (context) => {
    const input = context.client.graphQLClient.variable('input', 'CustomerAccessTokenCreateInput!');
    return context.client.graphQLClient.mutation('customerAccessTokenCreate', [input], (root) => {
        root.add('customerAccessTokenCreate', { args: { input } }, (customer) => {
            customer.add('customerAccessToken', (token) => {
                token.add('accessToken');
                token.add('expiresAt');
            });
            customer.add('customerUserErrors', (error) => {
                error.add('code');
                error.add('field');
                error.add('message');
            });
        });
    });
};
const signOutMutation = (context) => {
    const customerAccessToken = context.client.graphQLClient.variable('customerAccessToken', 'String!');
    return context.client.graphQLClient.mutation('customerAccessTokenDelete', [customerAccessToken], (root) => {
        root.add('customerAccessTokenDelete', { args: { customerAccessToken } }, (customer) => {
            customer.add('deletedAccessToken');
            customer.add('deletedCustomerAccessTokenId');
            customer.add('userErrors', (error) => {
                error.add('field');
                error.add('message');
            });
        });
    });
};
const signUpMutation = (context) => {
    const input = context.client.graphQLClient.variable('input', 'CustomerCreateInput!');
    return context.client.graphQLClient.mutation('customerCreate', [input], (root) => {
        root.add('customerCreate', { args: { input } }, (customer) => {
            customer.add('customer', (token) => {
                token.add('id');
            });
            customer.add('customerUserErrors', (error) => {
                error.add('code');
                error.add('field');
                error.add('message');
            });
        });
    });
};

/* eslint-disable @typescript-eslint/no-unused-vars */
// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function editProfile(context, params) {
    const { token, profile } = params;
    const data = {
        customerAccessToken: token,
        customer: profile
    };
    // send user data to authenticate, return token if valid
    return await context.client.graphQLClient.send(editProfileMutation(context), data).then(({ model }) => {
        return model;
    });
}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function getBlogPosts(context, params, customQuery) {
    // Use the built-in function
    const articlesQuery = context.client.graphQLClient.query((root) => {
        root.addConnection('articles', { args: { first: 20 } }, (article) => {
            article.add('title');
            article.add('handle');
            article.add('url');
            article.add('excerpt');
            article.add('publishedAt');
            article.addField('image', {}, (image) => {
                image.add('id');
                image.add('altText');
                image.add('originalSrc');
            });
            article.addField('authorV2', {}, (author) => {
                author.add('name');
                author.add('email');
            });
        });
    });
    // Call the send method with the custom query
    context.client.graphQLClient.send(articlesQuery).then(({ model, articles }) => {
        if (model) {
            return model.articles;
        }
    });
}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function getPages(context, params, customQuery) {
    // Use the built-in function
    if (params.slug) {
        const pageByHandleQuery = context.client.graphQLClient.query((root) => {
            root.add('pageByHandle', { args: { handle: params.slug } }, (pageByHandle) => {
                pageByHandle.add('id');
                pageByHandle.add('title');
                pageByHandle.add('handle');
                pageByHandle.add('url');
                pageByHandle.add('bodySummary');
                pageByHandle.add('body');
                pageByHandle.add('createdAt');
            });
        });
        // Call the send method with the custom query
        return context.client.graphQLClient.send(pageByHandleQuery).then(({ model, content }) => {
            return model.pageByHandle;
        });
    }
    else {
        const pagesQuery = context.client.graphQLClient.query((root) => {
            root.addConnection('pages', { args: { first: params.limit ? params.limit : 20 } }, (article) => {
                article.add('id');
                article.add('title');
                article.add('handle');
                article.add('url');
                article.add('bodySummary');
                article.add('body');
                article.add('createdAt');
            });
        });
        // Call the send method with the custom query
        return context.client.graphQLClient.send(pagesQuery).then(({ model, content }) => {
            if (model) {
                return model;
            }
        });
    }
}

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function updateCart(context, params, _customQuery) {
    const { currentCart, product, quantity } = params;
    // Existing Checkout ID
    const checkoutID = currentCart.id;
    product.id;
    // Add an item to the checkout
    return await context.client.checkout.updateLineItems(checkoutID, { id: product.id, quantity }).then((checkout) => checkout);
}

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function createCart(context, _params, _customQuery) {
    // initiate the cart
    return await context.client.checkout.create().then((checkout) => {
        // return checkOut ID
        return checkout.id;
    });
}

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function addToCart(context, params, _customQuery) {
    const { currentCart, product, quantity, customQuery } = params;
    // Existing Checkout ID
    const checkoutID = currentCart.id;
    // Items to be add to cart
    const lineItemsToAdd = [{
            variantId: product.variantBySelectedOptions && product.variantBySelectedOptions !== null ? product.variantBySelectedOptions.id : product.variantId,
            quantity,
            customAttributes: customQuery
        }];
    // Add an item to the checkout
    return await context.client.checkout.addLineItems(checkoutID, lineItemsToAdd).then((checkout) => checkout);
}

// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function removeFromCart(context, params, _customQuery) {
    const { currentCart, product } = params;
    // Existing Checkout ID
    const checkoutID = currentCart.id;
    // products to be remove
    const lineItemIdsToRemove = [
        product.id
    ];
    // Add an item to the checkout
    return await context.client.checkout.removeLineItems(checkoutID, lineItemIdsToRemove).then((checkout) => checkout);
}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function signUp(context, params, customQuery) {
    const data = {
        input: params
    };
    // send userdata to register
    return await context.client.graphQLClient.send(signUpMutation(context), data).then(({ model }) => {
        return model;
    });
}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function signIn(context, params, customQuery) {
    const { username, password } = params;
    const data = {
        input: {
            email: username,
            password
        }
    };
    // send user data to authenticate, return token if valid
    return await context.client.graphQLClient.send(signInMutation(context), data).then(({ model }) => {
        return model;
    });
}

/* eslint-disable @typescript-eslint/no-unused-vars */
// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function signOut(context, params) {
    const data = {
        customerAccessToken: params
    };
    // Remove customer access token
    return await context.client.graphQLClient.send(signOutMutation(context), data).then(({ model }) => {
        return model;
    });
}

/* eslint-disable @typescript-eslint/no-unused-vars */
// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function changePassword(context, params) {
    const { token, newPassword } = params;
    const data = {
        customerAccessToken: token,
        customer: {
            password: newPassword
        }
    };
    // Remove customer access token
    return await context.client.graphQLClient.send(changePasswordMutation(context), data).then(({ model }) => {
        return model;
    });
}

/* eslint-disable @typescript-eslint/no-unused-vars */
// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function forgotPassword(context, params) {
    const { username } = params;
    const data = {
        email: username
    };
    // Remove customer access token
    return await context.client.graphQLClient.send(forgotPasswordMutation(context), data);
}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function fetchCustomer(context, params, customQuery) {
    const getCustomeInfo = context.client.graphQLClient.query((root) => {
        root.add('customer', { args: { customerAccessToken: params } }, (customerInfo) => {
            customerInfo.add('id');
            customerInfo.add('displayName');
            customerInfo.add('email');
            customerInfo.add('firstName');
            customerInfo.add('lastName');
            customerInfo.add('phone');
            customerInfo.add('tags');
            customerInfo.add('acceptsMarketing');
        });
    });
    // send user data to authenticate, return token if valid
    return context.client.graphQLClient
        .send(getCustomeInfo)
        .then(({ model, product }) => {
        if (model) {
            return model;
        }
    });
}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function fetchOrders(context, params, customQuery) {
    const getCustomerOrders = context.client.graphQLClient.query((root) => {
        root.add('customer', { args: { customerAccessToken: params } }, (customerOrder) => {
            customerOrder.addConnection('orders', { args: { first: 20 } }, (order) => {
                order.add('id');
                order.add('name');
                order.add('orderNumber');
                order.add('processedAt');
                order.add('financialStatus');
                order.add('fulfillmentStatus');
                order.addField('currentTotalPrice', {}, (curTotPrice) => {
                    curTotPrice.add('amount');
                    curTotPrice.add('currencyCode');
                });
                order.addField('originalTotalPrice', {}, (originalTotalPrice) => {
                    originalTotalPrice.add('amount');
                    originalTotalPrice.add('currencyCode');
                });
                order.addField('originalTotalDuties', {}, (originalTotalDuties) => {
                    originalTotalDuties.add('amount');
                    originalTotalDuties.add('currencyCode');
                });
                order.addField('currentTotalTax', {}, (curTotTax) => {
                    curTotTax.add('amount');
                    curTotTax.add('currencyCode');
                });
                order.addField('currentSubtotalPrice', {}, (curSubTotPrice) => {
                    curSubTotPrice.add('amount');
                    curSubTotPrice.add('currencyCode');
                });
                order.addConnection('lineItems', { args: { first: 250 } }, (Lineitem) => {
                    Lineitem.add('title');
                    Lineitem.add('quantity');
                    Lineitem.addField('originalTotalPrice', {}, (originaldPrice) => {
                        originaldPrice.add('amount');
                        originaldPrice.add('currencyCode');
                    });
                    Lineitem.addField('variant', {}, (variant) => {
                        variant.add('sku');
                        variant.addField('product', {}, (parentProduct) => {
                            parentProduct.add('id');
                            parentProduct.add('handle');
                        });
                        variant.addField('image', {}, (parentProduct) => {
                            parentProduct.add('altText');
                            parentProduct.add('originalSrc');
                        });
                    });
                });
                order.addField('successfulFulfillments', {}, (trackingInfo) => {
                    trackingInfo.addField('trackingInfo', {}, (tracking) => {
                        tracking.add('number');
                        tracking.add('url');
                    });
                });
                order.addField('shippingAddress', {}, (saddress) => {
                    saddress.add('name');
                    saddress.add('phone');
                    saddress.add('formatted');
                });
                order.addField('totalShippingPriceV2', {}, (TotalShippingPrice) => {
                    TotalShippingPrice.add('amount');
                    TotalShippingPrice.add('currencyCode');
                });
            });
        });
    });
    return context.client.graphQLClient
        .send(getCustomerOrders)
        .then(({ model, product }) => {
        if (model) {
            return model;
        }
    });
}

/* eslint-disable func-names */
const addressesQuery = (pages, token, context) => {
    return context.client.graphQLClient.query((root) => {
        root.add('customer', {
            args: {
                customerAccessToken: token
            }
        }, (customer) => {
            customer.add('id');
            customer.addConnection('addresses', { args: { first: 10 } }, function (address) {
                address.add('address1');
                address.add('address2');
                address.add('city');
                address.add('company');
                address.add('firstName');
                address.add('lastName');
                address.add('name');
                address.add('phone');
                address.add('country');
                address.add('province');
                address.add('provinceCode');
                address.add('zip');
                address.add('formattedArea');
            });
        });
    });
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function fetchAddresses(context, params, customQuery) {
    // send user data to authenticate, return token if valid
    const addresses = await context.client.graphQLClient.send(addressesQuery(10, params, context)).then(({ model }) => {
        if (model) {
            return model.customer;
        }
    });
    return addresses;
}

/* eslint-disable @typescript-eslint/no-unused-vars */
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function deleteAddress(context, params) {
    const { token, AddressId } = params;
    const data = {
        id: AddressId,
        customerAccessToken: token
    };
    const deletedAddressId = await context.client.graphQLClient.send(customerAddressDeleteMutation(context), data).then(({ model }) => {
        if (model) {
            return model.customerAddressDelete;
        }
    });
    return deletedAddressId;
}

/* eslint-disable @typescript-eslint/no-unused-vars */
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function addAddress(context, params) {
    const { token, address } = params;
    const data = {
        address,
        customerAccessToken: token
    };
    const addedAddressId = await context.client.graphQLClient.send(customerAddressAddMutation(context), data).then(({ model }) => {
        if (model) {
            return model.customerAddressCreate;
        }
    });
    return addedAddressId;
}

/* eslint-disable @typescript-eslint/no-unused-vars */
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function updateAddress(context, params) {
    const { token, AddressId, address } = params;
    const data = {
        id: AddressId,
        address,
        customerAccessToken: token
    };
    const updatedAddressId = await context.client.graphQLClient.send(customerAddressUpdateMutation(context), data).then(({ model }) => {
        if (model) {
            return model.customerAddressUpdate;
        }
    });
    return updatedAddressId;
}

// eslint-disable-next-line @typescript-eslint/no-unused-vars
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
async function checkOut(context, checkoutId, customQuery) {
    return context.client.checkout.fetch(checkoutId);
}

const CustomClient = require('shopify-buy/index.unoptimized.umd.min.js');
const defaultSettings = {};
const cookies = {
    cartCookieName: 'vsf-cart'
};
const onCreate = (settings) => {
    const client = CustomClient.buildClient(settings.api);
    client.apolloClient = shopifyApollo.createShopifyApollo(settings);
    return ({
        config: {
            ...defaultSettings,
            ...settings
        },
        client,
        cookies: (settings.api).cookies || cookies
    });
};
const { createApiClient } = core.apiClientFactory({
    onCreate,
    api: {
        getProduct,
        getCategory,
        getBlogPosts,
        getPages,
        editProfile,
        addToCart,
        updateCart,
        removeFromCart,
        signUp,
        signIn,
        signOut,
        changePassword,
        forgotPassword,
        fetchCustomer,
        fetchOrders,
        fetchAddresses,
        deleteAddress,
        addAddress,
        updateAddress,
        createCart,
        checkOut,
        cookies,
        ...shopifyApollo.getShopifyApolloAPIs()
    }
});

exports.createApiClient = createApiClient;
//# sourceMappingURL=index.js.map
